<!-- markdownlint-disable MD033 -->
# Configuration Fields

Field               | Type                  | Default         | Description
--------------------|-----------------------|-----------------|-------------------
`version`           | `string`              | **Required**    | **MUST** be `'1.3.x'` where `x` can be any positive integer.
_Services_          |                       |                 |
`servers`           | [Server][][]          | **Required\***  | A list of servers to be used to find and load the datasets.<br>\* This can be omitted when using the deprecated `serviceHost` and `dataServers` fields.
`shortenerForURL`   | [URLShortenerCreator][] | **Optional**  | If provided, will be called to know how to shorten a given URL. Used, for example, when user clicks on the "Share" button. For more info see [URL Shortener][].
_Map_               |                       |                 |
`projection`        | `string`              | **Required**    | A string identifying the Well Known Identifier for the projection. Specifies the projection of the map.
`maxExtent`         | `number[4]`           | **Required**    | The maximum extent of the map defined as `[left, bottom, right, top]` all in the projection `projection`.
`restrictedExtent`  | `number[4]`           | `maxExtent`     | The maximum navigable extent of the map defined as `[left, bottom, right, top]` all in the projection `projection`. If set to `null`, map navigation will be unrestricted.
`zoomOffset`        | `integer >= 0`        | `0`             | Some map providers (e.g. Bing maps) skip some zoom levels (i.e. Bing maps considers the zoom level `0` as level `1`), if it's the case you can use this field to set the offset (i.e. set it to `1`).
`defaultZoom`       | `integer >= 0`        | **Optional**    | If provided, will be used to set the zoom level of the map by default (if the `extent` or `zoom` are not set in the URL of the page).
`baseLayers`        | [Layer][][]           | **Required**    | A list of layers. It **MUST** contain at least one layer. One of these layers (by default the first one) will be used as the background layer of the map. These layers will be displayed in a list which can be toggled using the globe button in the top bar of Syntool allowing the user to switch between them.
`additionalLayers`  | [Layer][][]           | `[]`            | A list of layers that are always visible and placed above or below all products. For more info see [Additional Layers][].
_Timeline_          |                       |                 |
`colocActive`       | `boolean`             | `true`          | The default state of the coloc active toggle.
`currentDate`       | [Date][]              | **Optional**    | The default current datetime of the portal. If not given it will be set to the client's local date and time and then a find nearest will be executed. E.g. for `01/06/2006 12:00` use `new Date(Date.UTC(2006, 5, 1, 12))`, for more info see [MDN's Date.UTC][].
`animationSpeed`    | `number > 0`          | 2.5 hours / s   | The base speed of the animations in _milliseconds of virtual time_ per _second of real time_.
`timeRanges`        | [TimeRange][][]       | _see below_[^1] | A list of predefined timespans that the users can select.
`yearsRange`        | `integer[2] > 1969`   | _see below_[^2] | Timeline years range from January 1st to January 1st (which means the upper bound will not appear in the timeline)
_Misc_              |                       |                 |
`storageId`         | `string`              | **Required**    | Portals that have the same `storageId` and the same domain will share the same local storage (local hotspots and user shapes).
`changelogURL`      | `URL`                 | **Optional**    | The URL of a [GitHub Flavored Markdown][] file containing the change log.
`importPolicyForURL`| [ImportPolicyFn][]    | **Optional**    | The function that will be called for each URL that needs to be imported automatically to determine if that operation should be allowed, denied, or otherwise the user should be asked with a prompt (the default).
`maxDatasetsWeight` | `number >= 0`         | `100`           | The maximum cumulated weight of datasets rendered at the same time. For more info see [Pagination][].
`markerSymbols`     | [MarkerSymbols][]     | `{}`            | A hash map of polygons to be referenced in the `graphicName` of a [PolygonMarkerStyle][].
`groupProductsBy`   | `false` or `string`   | `false`         | If set to a `string`, will be used to choose the tags to group the products by. Otherwise the products will not be grouped.
`defaultGroupLabel` | `string`              | **Optional**    | If provided, will be used as label to the default group.
`collapsibleGroups` | `boolean`             | `false`         | If set to `true`, clicking on a group label will show/hide its contents in the products panel. Only applicable when grouping products. (See `showGroups` and `groupProductsBy`)
`sortGroups`        | [SortGroupsFn][]      | **Optional**    | If provided, gets called before displaying the groups in the products list in order to sort them.
_Predefined Data_   |                       |                 |
`messages`          | [Message][][]         | `[]`            | A list of predefined ordered messages.
`hotspots`          | [Hotspot][][]         | `[]`            | A list of predefined ordered hotspots.
`drawableShapes`    | [DrawableShape][][]   | `[]`            | A list of predefined drawable shapes that the users can use to draw user shapes. (Some shapes are defined in Syntool and can't be removed like: polygon, polyline, and point).
`products`          | [Product][][]         | `[]`            | An ordered list of available products.

## Notes

* All server IDs **MUST** be unique (no two servers can have the same `id`).
* All product IDs **MUST** be unique (no two products can have the same `id`).
* The `products` list **MUST** contain exactly one [User Shapes product][].
* The [User Shapes product][] will be used for the user created shapes.
* All message IDs **MUST** be unique (no two messages can have the same `id`).
* If `servers` is used, all products **MUST** be handled by at least one server
(except for [User Shapes][User Shapes product], [Server Shapes][Server Shapes
product] and [Layer][Layer product] products which are handled internally only).

<details><summary>Deprecated fields</summary>

Field         | Type        | Description
--------------|-------------|-------------------
`serviceHost` | `URL`       | _Deprecated: Use `servers` instead._<br>The URL to the server running a Syntool services server (or a compatible one).
`dataServers` | `URL[]`     | _Deprecated: Use `servers` instead._<br>A list of URLs to use for requesting data (tiles, GeoJSON, ...). All URLs **MUST** be equivalent, a list is given in order to circumvent the browser's limitation on the number of simultaneous requests to one domain.
`showGroups`  | `boolean`   | _Deprecated: Use `groupProductsBy` instead._<br>If set to `true`, the products will be grouped in the products panel, if possible.
`groups`      | [Group][][] | _Deprecated: Use product's `tags` and `groupProductsBy` instead._<br>An ordered list of groups.

> **Note:** If `groups` are defined, All products **MUST** be in at least one
> group.

</details>

[^1]:
    `timeRanges` default value

    ```js
    [
      ['6-Hour', '6h'],
      ['Daily', '1d', true],
      ['3-Day', '3d'],
      ['Weekly', '1w'],
      ['Bi-weekly', '2w'],
    ]
    ```

[^2]:
    `yearsRange` default value

    The default value for the `yearsRange` property is dynamically generated so
    that the timeline displays the last 15 years and the current year (16 years
    in total).

## Additional Layers

Additional layers are [Layers][Layer] with an optional additional custom option
`syntoolIsOverlay`. `syntoolIsOverlay` defaults to `false` and when set to
`true` the layer is displayed above all products. Otherwise it's displayed under
all products.

The order of the layer specifies the order in which they get rendered:

* The first element of the list is closest to the base layer and displayed
below all other layers of the same group (with the same value `syntoolIsOverlay`).
* The last element of the list is farthest from the base layer and displayed
above all other layers of the same group (with the same value `syntoolIsOverlay`).

[Pagination]: 10_ui.md#pagination
[Server]: 22_config-servers.md#server
[Product]: 23_config-products.md#product
[Layer product]: 24_config-product-types.md#layer
[User Shapes product]: 24_config-product-types.md#user-shapes
[Server Shapes product]: 24_config-product-types.md#server-shapes
[MarkerSymbols]: 24_config-product-types.md#markersymbols
[PolygonMarkerStyle]: 24_config-product-types.md#polygonmarkerstyle
[DrawableShape]: 25_config-annotations.md#drawableshape
[URL Shortener]: 26_config-types.md#url-shortener
[URLShortenerCreator]: 26_config-types.md#urlshortenercreator
[SortGroupsFn]: 26_config-types.md#sortgroupsfn
[Message]: 26_config-types.md#message
[Hotspot]: 26_config-types.md#hotspot
[Layer]: 26_config-types.md#layer
[TimeRange]: 26_config-types.md#timerange
[ImportPolicyFn]: 26_config-types.md#importpolicyfn
[Group]: 26_config-types.md#group-deprecated-use-products-tags-and-groupproductsby-instead

[Additional Layers]: #additional-layers

[Date]: https://developer.mozilla.org/en/docs/Web/JavaScript/Reference/Global_Objects/Date
[MDN's Date.UTC]: https://developer.mozilla.org/en/docs/Web/JavaScript/Reference/Global_Objects/Date/UTC
[GitHub Flavored Markdown]: https://github.github.com/gfm/
